# spec file for package libmediainfo
#
# Copyright (c) 2016 Packman Team <packman@links2linux.de>
# Copyright (c) 2007-2010 oc2pus
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.links2linux.org/
#


%define soname	0
Name:           libmediainfo
Version:        0.7.89
Release:        1.4
Summary:        Supplies technical and tag information about a video or audio file
License:        GPL-2.0+
Group:          System/Libraries
Url:            http://mediainfo.sourceforge.net/
Source:         https://sourceforge.net/projects/mediainfo/files/source/libmediainfo/%{version}/libmediainfo_%{version}.tar.xz
BuildRequires:  doxygen
BuildRequires:  fdupes
BuildRequires:  gcc-c++
BuildRequires:  libcurl-devel
BuildRequires:  libmms-devel
BuildRequires:  libtool
BuildRequires:  libzen-devel
BuildRequires:  pkgconfig
BuildRequires:  zlib-devel
BuildRequires:  pkgconfig(glib-2.0)
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
MediaInfo supplies technical and tag information about a video or
audio file.

%package -n %{name}%{soname}
Summary:        Supplies technical and tag information about a video or audio file
Group:          System/Libraries

%description -n %{name}%{soname}
MediaInfo supplies technical and tag information about a video or
audio file.

What information can I get from MediaInfo?
* General: title, author, director, album, track number, date, duration...
* Video: codec, aspect, fps, bitrate...
* Audio: codec, sample rate, channels, language, bitrate...
* Text: language of subtitle
* Chapters: number of chapters, list of chapters

DivX, XviD, H263, H.263, H264, x264, ASP, AVC, iTunes, MPEG-1,
MPEG1, MPEG-2, MPEG2, MPEG-4, MPEG4, MP4, M4A, M4V, QuickTime,
RealVideo, RealAudio, RA, RM, MSMPEG4v1, MSMPEG4v2, MSMPEG4v3,
VOB, DVD, WMA, VMW, ASF, 3GP, 3GPP, 3GP2

What format (container) does MediaInfo support?
* Video: MKV, OGM, AVI, DivX, WMV, QuickTime, Real, MPEG-1,
  MPEG-2, MPEG-4, DVD (VOB) (Codecs: DivX, XviD, MSMPEG4, ASP,
  H.264, AVC...)
* Audio: OGG, MP3, WAV, RA, AC3, DTS, AAC, M4A, AU, AIFF
* Subtitles: SRT, SSA, ASS, SAMI

This package contains the shared library for MediaInfo(-gui).

%package -n libmediainfo-devel
Summary:        Include files and libraries for development
Group:          Development/Libraries/C and C++
Requires:       %{name}%{soname} = %{version}
Requires:       glibc-devel
Requires:       libcurl-devel
Requires:       libmms-devel
Requires:       libzen-devel
Requires:       zlib-devel

%description -n libmediainfo-devel
Include files and mandatory libraries for development.

%prep
%setup -q -n MediaInfoLib
cp Release/ReadMe_DLL_Linux.txt \
    ReadMe.txt
mv History_DLL.txt \
    History.txt

sed -i 's/\r$//' *.txt *.html Source/Doc/Documentation.html
chmod 644 *.txt *.html Source/Doc/Documentation.html

%build
# generate docs
pushd Source/Doc
    doxygen -u 2> /dev/null
    doxygen Doxyfile
popd

export CFLAGS="%{optflags} -I%{_includedir}/libmms"
export CPPFLAGS="%{optflags} -I%{_includedir}/libmms"
export CXXFLAGS="%{optflags} -I%{_includedir}/libmms"

pushd Project/GNU/Library
    chmod +x autogen.sh
    ./autogen.sh
    %configure \
    	--enable-shared \
    	--disable-static \
    	--with-libcurl \
    	--with-libmms=%{_libdir}

    make %{?_smp_mflags}
popd

%install
pushd Project/GNU/Library/
%make_install
popd

# MediaInfoDLL headers and MediaInfo-config
for i in MediaInfo MediaInfoDLL; do
    install -dm 755 %{buildroot}%{_includedir}/$i
    install -m 644 Source/$i/*.h \
    	%{buildroot}%{_includedir}/$i
done

install -m 644 Source/MediaInfoDLL/MediaInfoDLL.cs \
    %{buildroot}%{_includedir}/MediaInfoDLL
install -m 644 Source/MediaInfoDLL/MediaInfoDLL.JNA.java \
    %{buildroot}%{_includedir}/MediaInfoDLL
install -m 644 Source/MediaInfoDLL/MediaInfoDLL.JNative.java \
    %{buildroot}%{_includedir}/MediaInfoDLL
install -m 644 Source/MediaInfoDLL/MediaInfoDLL.py \
    %{buildroot}%{_includedir}/MediaInfoDLL
install -m 644 Source/MediaInfoDLL/MediaInfoDLL3.py \
    %{buildroot}%{_includedir}/MediaInfoDLL

sed -i -e 's|Version: |Version: %{version}|g' \
    Project/GNU/Library/libmediainfo.pc
install -dm 755 %{buildroot}%{_libdir}/pkgconfig
install -m 644 Project/GNU/Library/libmediainfo.pc \
    %{buildroot}%{_libdir}/pkgconfig

rm Doc/installdox || true
rm %{buildroot}%{_libdir}/libmediainfo.la
%fdupes -s %{buildroot}/%{_datadir}

%post   -n libmediainfo%{soname} -p /sbin/ldconfig
%postun -n libmediainfo%{soname} -p /sbin/ldconfig

%files -n %{name}%{soname}
%defattr(-,root,root,-)
%doc History.txt License.html ReadMe.txt
%{_libdir}/libmediainfo.so.%{soname}
%{_libdir}/libmediainfo.so.%{soname}.*

%files -n libmediainfo-devel
%defattr(-,root,root,-)
%doc Changes.txt Source/Doc/Documentation.html
%doc Doc/*
%{_includedir}/MediaInfo/
%{_includedir}/MediaInfoDLL/
%{_libdir}/libmediainfo.so
%{_libdir}/pkgconfig/*.pc

%changelog
* Thu Oct  6 2016 aloisio@gmx.com
- Update to version 0.7.89
  * I changed some elements in the interface.
    No break in binary compatibily (no crash), but some
    details.
  0.7.79 --> 0.7.80
  * Visual Basic binding: StreamKind.Visual changed to
    StreamKind.Video for more coherency with other bindings
    (StreamKind.Visual is still available but it is deprecated)
  0.7.73 --> 0.7.74
  * EBUCore: Source/Material moved from timecodeStart to
  timecodeTrack
  * AES3: generic term AES3 replaced by more precise SMPTE
    ST numbers (302, 331, 337)
  0.7.72 --> 0.7.73
  * Clean aperture size is move from width/height to its own
    field
  * HEVC: format_Profile field changed from Profile@Level to
    Profile@Level@Tier
  * MXF: writing library and writing application fields are
    cleaned up, you may face some incompatibility or different
    values
  * AVC and HEVC: Level x.0 are replaced by Level x, because
    specs have no .0
  0.7.71 --> 0.7.72
  * EBUCore 1.5 output is slighly modified, check the
    compatibility with your workflow
  * PBCore2: codecid changed
  0.7.70 --> 0.7.71
  * Time code striped/not striped information is moved from
    "Format_Settings" to "TimeCode_Striped"
  0.7.69 --> 0.7.70
  * BitDepth: for very rare MXF containing PCM having
    quantization bits not same as stored bit depth, Stored bit
    depth has moved from "BitDepth" to "BitDepth_Stored".
    "BitDepth is the quantization bits value.
- Spec cleanup
* Thu Mar 27 2014 i@margueirte.su
- update version 0.7.67
  * MXF: duplicate display of some time code streams in ancillary data
  * B814, AAC: Wrong detection of audioObjectType==29
* Thu Feb 28 2013 fisiu@opensuse.org
- update to 0.7.62 (changes since 0.7.60):
  * MOV "menu" moved to "other", for better separation of time code tracks
  * "Intermediate Codec" is renamed to "AIC" (Apple Intermediate Codec)
  * MPEG-TS: Menu stream, KLVA_PID and SCTE35_PID removed and formats are in "Format" field
  * DTS: moved DTS endianess and word size
* Thu Oct  4 2012 i@marguerite.su
- update to 0.7.60
  * MPEG-TS/PS: improved detection of buggy time stamps
  * DPX: color primaries and transfer characteristics
  * MPEG-TS: Added support of scrambled streams without transport_scrambling_control bit set (e.g. PlayReady)
  * MPEG-TS: Name of some scrambling algorithms
  * MPEG-TS: detection of CBR/VBR at container level
  * MPEG Video: better detection of variable GOP
  * MPEG-TS: average, minimum, maximum PCR distance (hidden by default and you must parse the whole file with --ParseSpeed=1 option)
  * Matroska: some streams were wrongly detected sa VFR
  * #3538378, XML output: invalid characters, now if there is an invalid character, data is transported in base64
  * LXF: wrong video bit rate with some files
  * AC-3/E-AC-3: hang up with some Little Endian streams
  * AAC: wrong min and max bit rate in case of partial (default) parsing, disabling it
  * AVC: crash or hang up with some malformed/scrambled streams
  * Opus: wrong duration in case of non-48kHz stream
  * MOV: 25 fps + drop frame time codes were not handled correctly
* Sat May 19 2012 seife+obs@b1-systems.com
- add autoconf/automake/libtool to buildreq to fix 12.2 build
* Sat Jul 31 2010 toni@links2linux.de
- update to 0.7.34
* Mon May  3 2010 toni@links2linux.de
- update to 0.7.32
* Fri Apr 16 2010 toni@links2linux.de
- update to 0.7.31
* Fri Mar 26 2010 toni@links2linux.de
- update to 0.7.30
* Tue Mar  9 2010 toni@links2linux.de
- update to 0.7.29
* Sun Feb 21 2010 toni@links2linux.de
- update to 0.7.28
* Mon Jan 11 2010 toni@links2linux.de
- update to 0.7.27
* Wed Dec 23 2009 toni@links2linux.de
- update to 0.7.26
* Fri Nov 20 2009 toni@links2linux.de
- update to 0.7.25
* Fri Oct 30 2009 toni@links2linux.de
- update to 0.7.24
* Tue Oct 27 2009 toni@links2linux.de
- update to 0.7.23
* Tue Oct 13 2009 toni@links2linux.de
- update to 0.7.19
* Mon Jun 22 2009 toni@links2linux.de
- update to 0.7.17
* Wed May 20 2009 toni@links2linux.de
- update to 0.7.16
* Thu Apr 30 2009 toni@links2linux.de
- update to 0.7.15
* Fri Apr 17 2009 toni@links2linux.de
- update to 0.7.14
* Sun Apr  5 2009 toni@links2linux.de
- update to 0.7.13
* Sat Apr  4 2009 toni@links2linux.de
- redowngrade to 0.7.12
* Fri Apr  3 2009 toni@links2linux.de
- update to 0.7.13
* Fri Mar 20 2009 toni@links2linux.de
- update to 0.7.12
* Fri Feb 13 2009 toni@links2linux.de
- update to 0.7.11
* Fri Jan 30 2009 toni@links2linux.de
- update to 0.7.10
* Fri Jan 23 2009 toni@links2linux.de
- update to 0.7.9
* Tue Dec  9 2008 toni@links2linux.de
- update to 0.7.8
- docs are now generated with doxygen
* Wed Nov 19 2008 toni@links2linux.de
- rebuild with modified sources from author to fix gui problem
* Mon Nov 17 2008 toni@links2linux.de
- update to 0.7.7.8
* Mon Dec 10 2007 toni@links2linux.de
- libZenLib and libMediaInfoLib are renamed to libzen and libmediainfo
- install *-config files manually
- added devel-subpackages
- split off from MediaInfo package
